********************************************************************************
********************************************************************************
****
**** Replication file 2 for:
****   Gerber, Alan S., Gregory A. Huber, Daniel R. Biggers, and David J.
****     Hendry. "Why Don't People Vote in U.S. Primary Elections? Assessing
****     Theoretical Explanations for Reduced Participation." Electoral Studies.
****
****   This file uses the final dataset generated in
****   "01_ConstructFinalDataset.do" and creates and recodes variables for
****   analysis. 
****
********************************************************************************
********************************************************************************

log using Logs/02_RecodeVariables.txt, text replace

clear
set more off

** users should maintain the given directory structure and set the working
**   directory to be the location of this .do file
*cd ...

** read in data
use Data/PrimarySurveyWithContextVariables.dta, clear

** make everything lower-case
qui foreach var of varlist * {
  local temp = lower("`var'")
  rename `var' `temp'
}

** label primary rules variable
label var primaryrule "State Primary Rules (0 = Closed; 1 = Open)"

** label spending variables
label var totalspendingprimary_12 "Total District Campaign Spending (2012)"
label var dspend_12 "Total Dem. Campaign Spending in District (2012)"
label var rspend_12 "Total Rep. Campaign Spending in District (2012)"
label var totalspendingprimary_14 "Total District Campaign Spending (2014)"
label var dspend_14 "Total Dem. Campaign Spending in District (2014)"
label var rspend_14 "Total Rep. Campaign Spending in District (2014)"

** logged versions of spending variables
gen dlog_spend_12 = log(dspend_12 + 1)
gen dlog_spend_14 = log(dspend_14 + 1)
gen rlog_spend_12 = log(rspend_12 + 1)
gen rlog_spend_14 = log(rspend_14 + 1)
label var dlog_spend_12 "Logged Dem. Campaign Spending (2012)"
label var dlog_spend_14 "Logged Dem. Campaign Spending (2014)"
label var rlog_spend_12 "Logged Rep. Campaign Spending (2012)"
label var rlog_spend_14 "Logged Rep. Campaign Spending (2014)"

** everyone in sample voted in 2010 or 2012 general elections
gen voted_primaries_10and12 = (primary_2010 == 1) + (primary_2012 == 1)
gen voted_primaries_10or12 = (primary_2010 == 1) | (primary_2012 == 1)
gen voted_primary_10 = primary_2010 == 1
gen voted_primary_12 = primary_2012 == 1
label var voted_primary_10 "Voted in 2010 Primary (Yes = 1)"
label var voted_primary_12 "Voted in 2012 Primary (Yes = 1)"

** top-two primary flag (from la_wa_ca_flag)
gen type_top2primary = (la_wa_ca_flag == 1)
label var type_top2primary "Type of Primary is Top-two (Yes = 1)"

** had primary already happened?
gen type_hadprimary = (retrospect_primary == 1)
label var type_hadprimary "State Already Had Primary (Yes = 1)"

** partisanship (from pid3 and pid7)
gen dem = pid3 == 1
gen rep = pid3 == 2
gen ind = pid3 == 3 | pid3 == 4 | pid3 == 5
gen pid7_alt = pid7
replace pid7_alt = 4 if pid7 == 8
label var dem "Democrat (Yes = 1)"
label var rep "Republican (Yes = 1)"
label var ind "Independent/Other (Yes = 1)"
label define pidlabel 1 "Strong Democrat" 2 "Not Very Strong Democrat" 3 "Lean Democrat" 4 "Independent" 5 "Lean Republican" 6 "Not Very Strong Republican" 7 "Strong Republican"
label values pid7_alt pidlabel
label var pid7_alt "7 Point Partisanship (DK = Ind.)"

** social pressure questions by election type
foreach var of varlist yhp31* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (5 = 0) (* = .), /*
    */gen(socnorms_pres_`var')
}
label var socnorms_pres_yhp31a /*
  */"Presidential - If Don't Vote, Family/Friends Disappointed"
label var socnorms_pres_yhp31b /*
  */"Presidential - If Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_pres_yhp31c /*
  */"Presidential - Most of My Family/Friends Vote"
label var socnorms_pres_yhp31d /*
  */"Presidential - Most of My Family/Friends Stay Informed"
label var socnorms_pres_yhp31e /*
  */"Presidential - Family/Friends Will Find Out If I Don't Vote"
label var socnorms_pres_yhp31f /*
  */"Presidential - I Feel Bad If I Cannot Vote"
label var socnorms_pres_yhp31g /*
  */"Presidential - It is Important to Turn Out and Vote"

foreach var of varlist yhp32* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (5 = 0) (* = .), /*
    */gen(socnorms_house_`var')
}
label var socnorms_house_yhp32a /*
  */"House - If Don't Vote, Family/Friends Disappointed"
label var socnorms_house_yhp32b /*
  */"House - If Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_house_yhp32c "House - Most of My Family/Friends Vote"
label var socnorms_house_yhp32d /*
  */"House - Most of My Family/Friends Stay Informed"
label var socnorms_house_yhp32e /*
  */"House - Family/Friends Will Find Out If I Don't Vote"
label var socnorms_house_yhp32f "House - I Feel Bad If I Cannot Vote"
label var socnorms_house_yhp32g "House - It is Important to Turn Out and Vote"

foreach var of varlist yhp33* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (5 = 0) (* = .), /*
    */gen(socnorms_hprim_`var')
}
label var socnorms_hprim_yhp33a /*
  */"House Prim. - If Don't Vote, Family/Friends Disappointed"
label var socnorms_hprim_yhp33b /*
  */"House Prim. - If Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_hprim_yhp33c "House Prim. - Most of My Family/Friends Vote"
label var socnorms_hprim_yhp33d /*
  */"House Prim. - Most of My Family/Friends Stay Informed"
label var socnorms_hprim_yhp33e /*
  */"House Prim. - Family/Friends Will Find Out If I Don't Vote"
label var socnorms_hprim_yhp33f "House Prim. - I Feel Bad If I Cannot Vote"
label var socnorms_hprim_yhp33g /*
  */"House Prim. - It is Important to Turn Out and Vote"

* alternative codings, dropping DK responses
foreach var of varlist yhp31* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), /*
    */gen(socnorms_pres_`var'_alt)
}
label var socnorms_pres_yhp31a_alt /*
  */"Presidential - If Don't Vote, Family/Friends Disappointed"
label var socnorms_pres_yhp31b_alt /*
  */"Presidential - If Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_pres_yhp31c_alt /*
  */"Presidential - Most of My Family/Friends Vote"
label var socnorms_pres_yhp31d_alt /*
  */"Presidential - Most of My Family/Friends Stay Informed"
label var socnorms_pres_yhp31e_alt /*
  */"Presidential - Family/Friends Will Find Out If I Don't Vote"
label var socnorms_pres_yhp31f_alt "Presidential - I Feel Bad If I Cannot Vote"
label var socnorms_pres_yhp31g_alt /*
  */"Presidential - It is Important to Turn Out and Vote"

foreach var of varlist yhp32* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), /*
    */gen(socnorms_house_`var'_alt)
}
label var socnorms_house_yhp32a_alt /*
  */"House - If Don't Vote, Family/Friends Disappointed"
label var socnorms_house_yhp32b_alt /*
  */"House - If Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_house_yhp32c_alt "House - Most of My Family/Friends Vote"
label var socnorms_house_yhp32d_alt /*
  */"House - Most of My Family/Friends Stay Informed"
label var socnorms_house_yhp32e_alt /*
  */"House - Family/Friends Will Find Out If I Don't Vote"
label var socnorms_house_yhp32f_alt "House - I Feel Bad If I Cannot Vote"
label var socnorms_house_yhp32g_alt /*
  */"House - It is Important to Turn Out and Vote"

foreach var of varlist yhp33* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), /*
    */gen(socnorms_hprim_`var'_alt)
}
label var socnorms_hprim_yhp33a_alt /*
  */"House Prim. - If Don't Vote, Family/Friends Disappointed"
label var socnorms_hprim_yhp33b_alt /*
  */"House Prim. - If Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_hprim_yhp33c_alt /*
  */"House Prim. - Most of My Family/Friends Vote"
label var socnorms_hprim_yhp33d_alt /*
  */"House Prim. - Most of My Family/Friends Stay Informed"
label var socnorms_hprim_yhp33e_alt /*
  */"House Prim. - Family/Friends Will Find Out If I Don't Vote"
label var socnorms_hprim_yhp33f_alt "House Prim. - I Feel Bad If I Cannot Vote"
label var socnorms_hprim_yhp33g_alt /*
  */"House Prim. - It is Important to Turn Out and Vote"

** excuses by election type
foreach var of varlist yhp34* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), gen(excuse_pres_`var')
}
label var excuse_pres_yhp34a /*
  */"Presidential - I Didn't Know Enough About Candidates"
label var excuse_pres_yhp34b "Presidential - Moved, So Wasn't Aware of Election"
label var excuse_pres_yhp34c /*
  */"Presidential - Didn't Think It Would Matter Who Won"
label var excuse_pres_yhp34g "Presidential - Didn't Realize It Was Election Day"

foreach var of varlist yhp35* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), gen(excuse_house_`var')
}
label var excuse_house_yhp35a "House - I Didn't Know Enough About Candidates"
label var excuse_house_yhp35b "House - Moved, So Wasn't Aware of Election"
label var excuse_house_yhp35c "House - Didn't Think It Would Matter Who Won"
label var excuse_house_yhp35g "House - Didn't Realize It Was Election Day"

foreach var of varlist yhp36* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), gen(excuse_hprim_`var')
}
label var excuse_hprim_yhp36a /*
  */"House Primary - I Didn't Know Enough About Candidates"
label var excuse_hprim_yhp36b /*
  */"House Primary - Moved, So Wasn't Aware of Election"
label var excuse_hprim_yhp36c /*
  */"House Primary - Didn't Think It Would Matter Who Won"
label var excuse_hprim_yhp36d /*
  */"House Primary - Not a Good Representative of Either Party"
label var excuse_hprim_yhp36e /*
  */"House Primary - Didn't Know Enough to Pick Primary Candidates"
label var excuse_hprim_yhp36f /*
  */"House Primary - Thought All Primary Candidates Were Same"
label var excuse_hprim_yhp36g /*
  */"House Primary - Didn't Realize It Was Election Day"

** civic duty battery by election type
foreach var of varlist yhp24a yhp24c yhp24f {
  recode `var' (1 = 0) (2 = 0) (3 = 1) (* = .), gen(civicduty_`var')
}
label var civicduty_yhp24a "Vote in a Presidential General Election"
label var civicduty_yhp24c "Vote in a House General Election"
label var civicduty_yhp24f "Vote in a House Primary Election"

** norms about who ought to vote in a primary
foreach var of varlist yhp30* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), gen(primnorms_`var')
}
egen temp = rowmiss(primnorms_*)
gen num_primnorms_answered = 5 - temp
label var num_primnorms_answered /*
  */"Number of Primary Norms Questions Answered (out of 5)"
drop temp
label var primnorms_yhp30a /*
  */"Only Those Committed to Party's Candidate Should Vote in Its Primary"
label var primnorms_yhp30b /*
  */"Only Those Who Strongly Identify with Party Should Vote in Its Primary"
label var primnorms_yhp30c "Independents Should Not Vote in Party Primaries"
label var primnorms_yhp30d /*
  */"Party Members Should Feel Obligated to Vote in Their Party's Primary"
label var primnorms_yhp30e "It Would Be Wrong to Vote in Other Party's Primary"

** deference battery
foreach var of varlist yhp15 yhp16 {
  gen def_`var' = (`var' - 1) / 6
  replace def_`var' = . if def_`var' < 0 | def_`var' > 1
}
label var def_yhp15 "People Who Care the Most Should Vote"
label var def_yhp16 "People Who Know the Most Should Vote"

** evaluations of voting in different types of elections
foreach var of varlist yhp25* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), gen(electype_pres_`var')
}
label var electype_pres_yhp25a /*
  */"Presidential - Well Qualified to Choose Candidate to Vote For"
label var electype_pres_yhp25b /*
  */"Presidential - My Vote Matters a Great Deal For Who Wins"
label var electype_pres_yhp25c /*
  */"Presidential - Outcome of Election Has Big Effect On My Life"
label var electype_pres_yhp25e /*
  */"Presidential - If I Don't Vote, Others Will Do Good Job of Picking Candidate"
label var electype_pres_yhp25h /*
  */"Presidential - I Know a Great Deal About Each Candidate"
label var electype_pres_yhp25i /*
  */"Presidential - Easy to Figure Out Which Candidate to Vote For"

foreach var of varlist yhp26* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), /*
    */gen(electype_house_`var')
}
label var electype_house_yhp26a /*
  */"House - Well Qualified to Choose Candidate to Vote For"
label var electype_house_yhp26b /*
  */"House - My Vote Matters a Great Deal For Who Wins"
label var electype_house_yhp26c /*
  */"House - Outcome of Election Has Big Effect On My Life"
label var electype_house_yhp26e /*
  */"House - If I Don't Vote, Others Will Do Good Job of Picking Candidate"
label var electype_house_yhp26h /*
  */"House - I Know a Great Deal About Each Candidate"
label var electype_house_yhp26i /*
  */"House - Easy to Figure Out Which Candidate to Vote For"

* yhp27: house primary (note that original labels from YouGov are wrong)
foreach var of varlist yhp27* yhp28* {
  recode `var' (1 = 1) (2 = 1) (3 = 0) (4 = 0) (* = .), /*
  */gen(electype_hprim_`var')
}
label var electype_hprim_yhp27a /*
  */"House Prim. - Well Qualified to Choose Candidate to Vote For"
label var electype_hprim_yhp27b /*
  */"House Prim. - My Vote Matters a Great Deal For Who Wins"
label var electype_hprim_yhp27c /*
  */"House Prim. - Outcome of Election Has Big Effect On My Life"
label var electype_hprim_yhp27e /*
  */"House Prim. - If I Don't Vote, Others Will Do Good Job of Picking Candidate"
label var electype_hprim_yhp27h /*
  */"House Prim. - I Know a Great Deal About Each Candidate"
label var electype_hprim_yhp27i /*
  */"House Prim. - Easy to Figure Out Which Candidate to Vote For"
label var electype_hprim_yhp28d /*
  */"House Prim. - Might Vote For the Wrong Candidate"

** know/care battery
foreach var of varlist yhp17* {
  recode `var' (5 = 0) (4 = 0) (3 = 0) (2 = 1) (1 = 1) (* = .), gen(care_`var')
}

foreach var of varlist yhp18* {
  recode `var' (5 = 1) (4 = 1) (3 = 0) (2 = 0) (1 = 0) (* = .), /*
    */gen(knowmore_`var')
}

** survey covariates for regression controls
recode educ (1 = 1) (2 = 1) (3 = 2) (4 = 2) (5 = 3) (6 = 4), gen(educ_recoded)
gen D_educ2 = educ_recoded == 2
gen D_educ3 = educ_recoded == 3
gen D_educ4 = educ_recoded == 4
label var D_educ2 "Educ = HS"
label var D_educ3 "Educ = 4 year BA"
label var D_educ4 "Educ = Post Grad"

gen D_age = 2014 - birthyr
gen D_age2 = (D_age^2) / 100
label var D_age "Age in Years"
label var D_age2 "Age Squared / 100"

gen D_isfemale = gender == 2
label var D_isfemale "Female (Yes = 1)"

gen D_racenotwhite = race != 1
label var D_racenotwhite "Race is Not White"

gen D_polint2 = newsint == 2
gen D_polint3 = newsint == 3 | newsint == 4 | newsint == 7
label var D_polint2 "Political Interest = Some"
label var D_polint3 "Political Interest < Some"

gen D_pidstr2 = pid7_alt == 2 | pid7_alt == 6
gen D_pidstr3 = pid7_alt == 3 | pid7_alt == 5
gen D_pidstr4 = pid7_alt == 4
label var D_pidstr2 "PID = Weak Partisan"
label var D_pidstr3 "PID = Partisan Leaner"
label var D_pidstr4 "PID = Independent/Other"

recode faminc (1 = 1) (2 = 1) (3 = 1) (4 = 2) (5 = 2) (6 = 3) (7 = 3) (8 = 3) /*
  */(9 = 4) (10 = 4) (11 = 4) (12/97 = 5), gen(alt_inc)
gen D_inc1 = alt_inc == 1
gen D_inc2 = alt_inc == 2
gen D_inc4 = alt_inc == 4
gen D_inc5 = alt_inc == 5
gen D_incrf = faminc == 97
label var D_inc1 "Income Tercile = 1"
label var D_inc2 "Income Tercile = 3"
label var D_inc4 "Income Tercile = 4"
label var D_inc5 "Income Tercile = 5"
label var D_incrf "Income Refused"

** political knowledge
gen yhp50correct = yhp50 == 3
replace yhp50correct = . if yhp50 == .
label var yhp50correct "Knows Length of Senate Term (Yes = 1)"

gen yhp50correct_alt = yhp50 == 3
label var yhp50correct_alt "Alt - Knows Length of Senate Term (Yes = 1)"

gen yhp51correct = yhp51 == 4
replace yhp51correct = . if yhp51 == .
label var yhp51correct "Knows John Roberts's Office (Yes = 1)"

gen yhp51correct_alt = yhp51 == 4
label var yhp51correct_alt "Alt - Knows John Roberts's Office (Yes = 1)"

gen yhp52correct = yhp52 == 1
replace yhp52correct = . if yhp52 == .
label var yhp52correct "Knows Janet Yellen's Office (Yes = 1)"

gen yhp52correct_alt = yhp52 == 1
label var yhp52correct_alt "Alt - Knows Janet Yellen's Office (Yes = 1)"

gen yhp53correct = yhp53 == 1
replace yhp53correct = . if yhp53 == .
label var yhp53correct "Knows What Medicare is (Yes = 1)"

gen yhp53correct_alt = yhp53 == 1
label var yhp53correct_alt "Alt - Knows What Medicare is (Yes = 1)"

gen yhp54correct = yhp54 == 1
replace yhp54correct = . if yhp54 == .
label var yhp54correct "Knows Least is Spent on Foreign Aid (Yes = 1)"

gen yhp54correct_alt = yhp54 == 1
label var yhp54correct_alt "Alt - Knows Least is Spent on Foreign Aid (Yes = 1)"

egen knowledge = rowtotal(*correct)
foreach var of varlist *correct {
  replace knowledge = . if `var' == .
}
label var knowledge "Number of Correct Knowledge Items"

egen knowledge_alt = rowtotal(*correct_alt)
label var knowledge_alt "Alt - Number of Correct Knowledge Items"

** save final dataset for analysis
save Data/PrimarySurveyWithContextVariables-Recodes.dta, replace

clear

log close
